# Project

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | 
**description** | **str** |  | [optional] 
**organization_id** | **str** |  | 
**parent_project_id** | **str** |  | [optional] 
**project_level** | **float** |  | [optional] 
**parent_project** | [**Project**](Project.md) |  | [optional] 
**children_projects** | [**list[Project]**](Project.md) |  | [optional] 
**organization** | [**Organization**](Organization.md) |  | [optional] 
**models** | [**list[Model]**](Model.md) |  | [optional] 
**members** | [**list[ProjectMember]**](ProjectMember.md) |  | [optional] 
**model_jobs** | [**list[ModelJob]**](ModelJob.md) |  | [optional] 
**model_job_events** | [**list[ModelJobEvent]**](ModelJobEvent.md) |  | [optional] 
**model_job_statuses** | [**list[ModelJobStatus]**](ModelJobStatus.md) |  | [optional] 
**user_favorites** | [**list[UserFavorite]**](UserFavorite.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

